<?php

/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 */

/**
 * Flashmagz only works in WordPress 4.7 or later.
 */
if (version_compare($GLOBALS['wp_version'], '4.7', '<')) {
    require get_template_directory() . '/inc/back-compat.php';
    return;
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since  1.0.0
 */
function flashmagz_theme_setup() {

    // Make the theme available for translation.
    load_theme_textdomain('flashmagz', get_template_directory() . '/languages');

    // Add RSS feed links to <head> for posts and comments.
    add_theme_support('automatic-feed-links');

    /*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
    add_theme_support('title-tag');

    // Enable support for Post Thumbnails.
    add_theme_support('post-thumbnails');
    set_post_thumbnail_size(1170, 9999);

    // Declare image sizes.
    add_image_size('flashmagz-thumbnail-one', 340, 210, true);
    add_image_size('flashmagz-thumbnail-two', 340, 350, true);

    // Register custom navigation menu.
    register_nav_menus(
        array(
            'primary' => esc_html__('Primary Location', 'flashmagz'),
            'footer'  => esc_html__('Footer Location', 'flashmagz')
        )
    );

    /*
	* Switch default core markup for search form, comment form, and comments
	* to output valid HTML5.
	*/
    add_theme_support(
        'html5',
        array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
            'style',
            'script',
        )
    );

    // Setup the WordPress core custom background feature.
    add_theme_support('custom-background', apply_filters('flashmagz_custom_background_args', array(
        'default-color' => 'ffffff',
        'default-image' => '',
    )));

    // Enable theme-layouts extensions.
    add_theme_support(
        'theme-layouts',
        array(
            '1c'   => __('1 Column Wide (Full Width)', 'flashmagz'),
            '2c-l' => __('2 Columns: Content / Sidebar', 'flashmagz'),
            '2c-r' => __('2 Columns: Sidebar / Content', 'flashmagz')
        ),
        array('customize' => false, 'default' => '2c-l')
    );

    // This theme uses its own gallery styles.
    add_filter('use_default_gallery_style', '__return_false');

    // Indicate widget sidebars can use selective refresh in the Customizer.
    add_theme_support('customize-selective-refresh-widgets');

    // Adding support for core block visual styles.
    add_theme_support('wp-block-styles');

    // Add support for editor styles.
    add_theme_support('editor-styles');

    // Enqueue editor styles.
    add_editor_style('style-editor.css');

    // Add support for responsive embeds.
    add_theme_support('responsive-embeds');
}
add_action('after_setup_theme', 'flashmagz_theme_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function flashmagz_content_width() {
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters('flashmagz_content_width', 680);
}
add_action('after_setup_theme', 'flashmagz_content_width', 0);

if (!function_exists('flashmagz_content_width_full')) :
    /**
     * Set new content width if user uses 1 column layout.
     *
     * @since  1.0.0
     */
    function flashmagz_content_width_full() {
        global $content_width;

        if (in_array(get_theme_mod('theme_layout'), array('1c'))) {
            $content_width = 1007;
        }
    }
endif;
add_action('template_redirect', 'flashmagz_content_width_full');

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function flashmagz_skip_link_focus_fix() {
?>
    <script>
        /(trident|msie)/i.test(navigator.userAgent) && document.getElementById && window.addEventListener && window.addEventListener("hashchange", function() {
            var t, e = location.hash.substring(1);
            /^[A-z0-9_-]+$/.test(e) && (t = document.getElementById(e)) && (/^(?:a|select|input|button|textarea)$/i.test(t.tagName) || (t.tabIndex = -1), t.focus())
        }, !1);
    </script>
<?php
}
add_action('wp_print_footer_scripts', 'flashmagz_skip_link_focus_fix');

/**
 * Registers custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function flashmagz_widgets_init() {

    // Register ad widget.
    require get_template_directory() . '/inc/widgets/widget-ads.php';
    register_widget('Flashmagz_Ads_Widget');

    // Register video widget.
    require get_template_directory() . '/inc/widgets/widget-ads125.php';
    register_widget('Flashmagz_Ads125_Widget');

    // Register recent posts thumbnail widget.
    require get_template_directory() . '/inc/widgets/widget-recent.php';
    register_widget('Flashmagz_Recent_Widget');

    // Register popular posts thumbnail widget.
    require get_template_directory() . '/inc/widgets/widget-popular.php';
    register_widget('Flashmagz_Popular_Widget');

    // Register random posts thumbnail widget.
    require get_template_directory() . '/inc/widgets/widget-random.php';
    register_widget('Flashmagz_Random_Widget');

    // Register most views posts thumbnail widget.
    require get_template_directory() . '/inc/widgets/widget-views.php';
    register_widget('Flashmagz_Views_Widget');

    // Register twitter widget.
    require get_template_directory() . '/inc/widgets/widget-twitter.php';
    register_widget('Flashmagz_Twitter_Widget');

    // Register video widget.
    require get_template_directory() . '/inc/widgets/widget-video.php';
    register_widget('Flashmagz_Video_Widget');

    // Register home widget one column.
    require get_template_directory() . '/inc/widgets/widget-home-one-column.php';
    register_widget('Flashmagz_One_Column_Widget');

    // Register home widget v1.
    require get_template_directory() . '/inc/widgets/widget-home-two-columns.php';
    register_widget('Flashmagz_Two_Columns_Widget');

    // Register home widget three columns.
    require get_template_directory() . '/inc/widgets/widget-home-three-columns.php';
    register_widget('Flashmagz_Three_Columns_Widget');

    // Register home widget four columns.
    require get_template_directory() . '/inc/widgets/widget-home-four-columns.php';
    register_widget('Flashmagz_Four_Columns_Widget');

    // Register home widget four columns.
    require get_template_directory() . '/inc/widgets/widget-home-two-columns-alt.php';
    register_widget('Flashmagz_Two_Columns_Alt_Widget');

    // Register home widget four columns.
    require get_template_directory() . '/inc/widgets/widget-home-two-columns-alt-two.php';
    register_widget('Flashmagz_Two_Columns_Alt_Two_Widget');
}
add_action('widgets_init', 'flashmagz_widgets_init');

/**
 * Registers widget areas and custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function flashmagz_sidebars_init() {

    register_sidebar(
        array(
            'name'          => __('Home Sidebar', 'flashmagz'),
            'id'            => 'home',
            'description'   => __('Home sidebar to customize the content of your home page.', 'flashmagz'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => __('Primary Sidebar', 'flashmagz'),
            'id'            => 'primary',
            'description'   => __('Main sidebar that appears on the right.', 'flashmagz'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer 1', 'flashmagz'),
            'id'            => 'footer-1',
            'description'   => __('The footer sidebar 1st column.', 'flashmagz'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer 2', 'flashmagz'),
            'id'            => 'footer-2',
            'description'   => __('The footer sidebar 2nd column.', 'flashmagz'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer 3', 'flashmagz'),
            'id'            => 'footer-3',
            'description'   => __('The footer sidebar 3rd column.', 'flashmagz'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer 4', 'flashmagz'),
            'id'            => 'footer-4',
            'description'   => __('The footer sidebar 4th column.', 'flashmagz'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );
}
add_action('widgets_init', 'flashmagz_sidebars_init');

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Enqueue scripts and styles.
 */
require get_template_directory() . '/inc/scripts.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Require and recommended plugins list.
 */
require get_template_directory() . '/inc/plugins.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Customizer.
 */
require get_template_directory() . '/admin/customizer-library.php';
require get_template_directory() . '/admin/functions.php';

/**
 * Customizer functions.
 */
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/mods.php';

/**
 * Mega menus walker.
 */
require get_template_directory() . '/inc/megamenus/init.php';
require get_template_directory() . '/inc/megamenus/class-primary-nav-walker.php';

/**
 * We use some part of Hybrid Core to extends our themes.
 *
 * @link  http://themehybrid.com/hybrid-core Hybrid Core site.
 */
require get_template_directory() . '/inc/hybrid/attr.php';
require get_template_directory() . '/inc/hybrid/theme-layouts.php';

/**
 * Demo importer
 */
require get_template_directory() . '/inc/demo/demo-importer.php';
