<?php

/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @since  1.0.0
 * @param  array $args Configuration arguments.
 * @return array
 */
function flashmagz_page_menu_args($args) {
    $args['show_home'] = true;
    return $args;
}
add_filter('wp_page_menu_args', 'flashmagz_page_menu_args');

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function flashmagz_body_classes($classes) {

    // Adds a class of multi-author to blogs with more than 1 published author.
    if (is_multi_author()) {
        $classes[] = 'multi-author';
    }

    return $classes;
}
add_filter('body_class', 'flashmagz_body_classes');

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function flashmagz_post_classes($classes) {

    // Adds a class if a post hasn't a thumbnail.
    if (!has_post_thumbnail()) {
        $classes[] = 'no-post-thumbnail';
    }

    return $classes;
}
add_filter('post_class', 'flashmagz_post_classes');

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function flashmagz_excerpt_more($more) {
    return '&hellip;';
}
add_filter('excerpt_more', 'flashmagz_excerpt_more');

/**
 * Control excerpt length.
 *
 * @since 1.0.0
 */
function flashmagz_excerpt_length($length) {
    return 15;
}
add_filter('excerpt_length', 'flashmagz_excerpt_length', 999);

/**
 * Add category class to the menu
 *
 * @since 1.0.0
 */
function flashmagz_category_id_on_menu($classes, $item) {
    if ($item->object !== 'category') {
        return $classes;
    }

    $classes[] = 'category-' . $item->object_id . '-color';
    return $classes;
}
add_filter('nav_menu_css_class', 'flashmagz_category_id_on_menu', 10, 2);

/**
 * Remove theme-layouts meta box on attachment and bbPress post type.
 *
 * @since 1.0.0
 */
function flashmagz_remove_theme_layout_metabox() {
    remove_post_type_support('attachment', 'theme-layouts');
    remove_post_type_support('forum', 'theme-layouts');
    remove_post_type_support('topic', 'theme-layouts');
    remove_post_type_support('reply', 'theme-layouts');
}
add_action('init', 'flashmagz_remove_theme_layout_metabox', 11);

/**
 * Add post type 'post' support for the Simple Page Sidebars plugin.
 *
 * @since  1.0.0
 */
function flashmagz_page_sidebar_plugin() {
    include_once(ABSPATH . 'wp-admin/includes/plugin.php');
    if (is_plugin_active('simple-page-sidebars/simple-page-sidebars.php')) {
        add_post_type_support('post', 'simple-page-sidebars');
    }
}
add_action('init', 'flashmagz_page_sidebar_plugin');

/**
 * Filter the posts on category page.
 * Split the featured posts and the standard posts.
 *
 * @since  1.0.0
 */
function flashmagz_category_posts_filter($query) {

    // Theme prefix.
    $prefix = 'flashmagz-';

    // Get the data set in customizer.
    $tag = flashmagz_mod($prefix . 'featured-tag');

    if ($tag != '') {

        if (!is_admin() && $query->is_main_query()) {
            if ($query->is_category()) {
                $query->set('tag__not_in', $tag);
            }
        }
    }
}
add_action('pre_get_posts', 'flashmagz_category_posts_filter');

/**
 * Add custom fields to the author profile fields
 *
 * @since  1.0.0
 */
function flashmagz_new_contactmethods($contactmethods) {
    $contactmethods['twitter'] = __('Twitter Username', 'flashmagz'); // Add Twitter field
    return $contactmethods;
}
add_filter('user_contactmethods', 'flashmagz_new_contactmethods', 10, 1);

/**
 * Custom comment form fields.
 *
 * @since  1.0.0
 * @param  array $fields
 * @return array
 */
function flashmagz_comment_form_fields($fields, $args = array()) {

    $args = wp_parse_args($args);
    if (!isset($args['format']))
        $args['format'] = current_theme_supports('html5', 'comment-form') ? 'html5' : 'xhtml';

    $commenter = wp_get_current_commenter();
    $req       = get_option('require_name_email');
    $aria_req  = ($req ? " aria-required='true'" : '');
    $html5     = 'html5' === $args['format'];

    $fields['author'] = '<p class="comment-form-author"><input class="txt" id="author" name="author" type="text" value="' . esc_attr($commenter['comment_author']) . '" size="30" placeholder="' . __('Name', 'flashmagz') . ($req ? ' *' : '') . '"' . $aria_req . ' /></p>';

    $fields['email'] = '<p class="comment-form-email"><input class="txt" id="email" name="email" ' . ($html5 ? 'type="email"' : 'type="text"') . ' value="' . esc_attr($commenter['comment_author_email']) . '" size="30" placeholder="' . esc_attr__('Email', 'flashmagz') . ($req ? ' *' : '') . '"' . $aria_req . ' /></p>';

    $fields['url'] = '<p class="comment-form-url"><input class="txt" id="url" name="url" ' . ($html5 ? 'type="url"' : 'type="text"') . ' value="' . esc_attr($commenter['comment_author_url']) . '" size="30" placeholder="' . esc_attr__('Website', 'flashmagz') . '" /></p>';

    return $fields;
}
add_filter('comment_form_default_fields', 'flashmagz_comment_form_fields');

/**
 * Inject custom content to the comment form.
 *
 * @since  1.0.0
 */
function flashmagz_comment_custom() {

    // Add comment notes after comment form
    echo '<p class="comment-form-desc">' . __('Your email address will not be published. Required fields are marked *', 'flashmagz') . '</p>';

    // Custom comment button
    echo '<p class="form-submit-clone"><button class="btn" name="submit" type="submit" id="submit">' . esc_attr__('Post Comment', 'flashmagz') . '</button></p>';
}
add_action('comment_form', 'flashmagz_comment_custom');
